#!/usr/bin/perl -w

# testsubmit.pl
# Copyright (c) 2011, Casey Connor
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#      list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#      this list of conditions and the following disclaimer in the documentation
#      and/or other materials provided with the distribution.
#    - Neither the name of Lacinato nor the names of its contributors may be used to
#      endorse or promote products derived from this software without specific prior
#      written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# Version 1.0
# Casey Connor -- lacinato.com
# http://lacinato.com/cm/software/emailrelated/bdkim

# This script can be used to test submissions directly to BDKIM (it does not use the
# Java-side client).

# It will send a file to the BDKIM process and print the results that it recieves to
# stdout. This is useful as-is for testing only -- e.g. if you want to roll your own BDKIM
# client (which doesn't have to be Java-based) and want to see the BDKIM server output directly.

# You must configure the port information and filename below! The defaults will almost certainly not work!

# You should consider the setting of "should_clean_lines" in the BDKIM.conf file, which defaults to false.

# To use/test early-exit mode on the server, at the start of your message file put a line consisting of
# "EE" - but note that the line must end with the equivalent of the perl code "\015\012" if
# should_clean_lines is "0". (In java that's "\r\n").

# This script could obviously be improved very easily. :-) E.g. to accept a filename and port on the command
# line.

# IO::Socket
use IO::Socket;

my $host = 'localhost';
my $port = 12300;
my $MESSAGE_FILENAME = "/home/bdkim/test_message.txt";

# open up connection
my $sock = new IO::Socket::INET(PeerAddr => $host, PeerPort => $port, Proto => 'tcp');

$sock or die "connection failed:$!";

# read file into memory
open (FH, "<", $MESSAGE_FILENAME) || die "open of test file failed";
my $count = read (FH, $buf, 20480000);
close (FH);

print ("read $count bytes\n");

# write the file
syswrite ($sock, $buf, $count, 0);
$sock->shutdown(1);

# read back the results
my $result;

while (read ($sock, $result, 4096, 0) > 0) { 
  print ($result);
}

close $sock;
